@@ -15,7 +15,7 @@ class QDBusMessage;
 class KdedAdaptor : public QDBusAbstractAdaptor
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.kded5")
+    Q_CLASSINFO("D-Bus Interface", "org.kde.kded6")
 public:
     KdedAdaptor(QObject *parent);
 
@@ -27,8 +27,6 @@ public Q_SLOTS:
     void registerWindowId(qlonglong windowId, const QDBusMessage &);
     void unregisterWindowId(qlonglong windowId, const QDBusMessage &);
     void reconfigure();
-    // TODO KF6 remove
-    void loadSecondPhase();
     void quit();
 
     /**
